import json


class BaseConfig():
    def __init__(self, config):
        self.__config = config
        
        for key, value in self.__config.items():
            setattr(self, key, BaseConfig(value) if type(value) == dict else value)

    def keys(self):
        for key in self.__config.keys():
            yield key

    def values(self):
        for key in self.__config.keys():
            yield getattr(self, key)
    
    def items(self):
        for key in self.__config.keys():
            yield key, getattr(self, key)


class Config(BaseConfig):
    def __init__(self, config_file, encoding='utf-8'):
        self.__file = config_file

        self._load_config(encoding)

    def _load_config(self, encoding):
        with open(self.__file, "r", encoding=encoding) as config_file:
            config = json.loads(config_file.read())

            super().__init__(config)




from setuptools import setup, find_packages

setup(
    name='configureout',
    version='1.1',
    description='A simple configuration module',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='EightShift',
    author_email='the8shift@gmail.com',
    url='https://github.com/EightShift/configureout',
    packages=find_packages(),
    install_requires=[
        'jsonschema',  # Assuming you have any dependencies
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)